@@ -11,11 +11,10 @@ import shutil
 import subprocess
 import sys
 import typing as t
-from distutils.version import LooseVersion
 from typing import Dict, Generic, KeysView, List, Optional, TypeVar, Union, overload
 
 from . import exc
-from ._compat import console_to_str, str_from_console
+from ._compat import LooseVersion, console_to_str, str_from_console
 
 if t.TYPE_CHECKING:
     from typing_extensions import Literal
@@ -219,7 +218,7 @@ class tmux_cmd:
 
     Equivalent to:
 
-    .. code-block:: bash
+    .. code-block:: console
 
         $ tmux new-session -s my session
 
@@ -233,7 +232,7 @@ class tmux_cmd:
     def __init__(self, *args: t.Any, **kwargs: t.Any) -> None:
         tmux_bin = shutil.which("tmux")
         if not tmux_bin:
-            raise (exc.TmuxCommandNotFound)
+            raise exc.TmuxCommandNotFound()
 
         cmd = [tmux_bin]
         cmd += args  # add the command arguments to cmd
